import requests 


__all__ = ["Neso"]


class Neso:
    def __init__(self, callisto=None, org=None):
        self.callisto = callisto 
        self.org = org 

    def get_sensors(self):
        sensor_url = f'{self.callisto.host}/neso/api/v1/sensor'

        response  = requests.get(sensor_url, headers=self.callisto.headers)

        if response.status_code == 200:
            sensors = response.json()['data']
            return {sensor["id"]: sensor for sensor in sensors}

        else:
            print(f"Sensor details cannot be retrieved")
            return None


import os
import click
import json
import getpass
from appdirs import user_config_dir

from colorama import Fore, Style

from engine import __version__ as version

from colorama import init

from engine.connections import Callisto
from engine.libs.inquirer import text 

from .project import projects 
from .experiment import experiment


@click.group()
@click.version_option(version, message='%(version)s')
def cli():
    config_dir = user_config_dir('engine')
    if not os.path.exists(config_dir):
        os.makedirs(config_dir)
    if not os.path.exists(os.path.join(config_dir, "config.json")):
        fout = open(os.path.join(config_dir, "config.json"), "w")
        json.dump({"host": 'https://api.granular.ai',
                    "org":  None, 
                   "email": None}, fout)
        fout.close()

@click.command()
@click.option('--host', required=False, type=str, 
                default='https://api.granular.ai', 
                help='Platform root address')
@click.option('--relogin', required=False, is_flag=True)
def login(host, relogin):
    """Login on GeoEngine platform

    Examples:

    \b
    $ engine login 
    """
    if host:
        if "https://" not in host:
            host = "https://" + host

    callisto = Callisto()
    if not relogin and callisto.user:
        print (Fore.GREEN + callisto.user['email'] + Style.RESET_ALL + 
              " already logged in.")
        print ("Use " + Fore.YELLOW + "engine login --relogin" +  
                Style.RESET_ALL + " to login from a different account.")
    else:
        email = text(message="Email")
        password = getpass.getpass()

        callisto = Callisto(email=email, password=password, host=host)
        if callisto.user:
            print (Fore.GREEN + callisto.user['email'] + Style.RESET_ALL + 
                   " successfully logged on " + Fore.CYAN + callisto.host + 
                   Style.RESET_ALL)
 
@click.command()
def logout():
    """Logout from GeoEngine platform

    Examples:

    \b
    $ engine logout 
    """
    callisto = Callisto()
    if callisto.user:
        callisto.logout()
        if not callisto.user:
            click.echo("Logged out.")
    else:
        click.echo("Not signed in.")

cli.add_command(login)
cli.add_command(logout)
cli.add_command(projects)
# cli.add_command(experiment)


if __name__ == "__main__":
    init(autoreset = True, warp = False) 
    cli()



import json
import requests 

from tabulate import tabulate 


__all__ = ["Dione"]

class Dione:
    def __init__(self, callisto=None, org=None):
        self.callisto = callisto
        self.org = org

    def create_experiment(self, experiment):
        assert self.org, "No org slug passed"
        assert "projectId" in experiment, "No projectId given"
        assert experiment["projectId"], "No projectId given"
        assert "exportId" in experiment, "No exportId given"
        assert experiment["exportId"], "No exportId given"

        url = f'{self.callisto.host}/dione/api/v1/experiments?orgId={self.org}'
        response = requests.post(url=url, data=json.dumps(experiment), 
                                 headers=self.callisto.headers)

        if response.status_code == 200:
            experiment_id = response.json()["experiment"]["id"]
            return experiment_id
        else:
            print (response.json())
            print ("Failed to create experiment")
            return None

    def add_best_model(self, experimentId, model_path):
        assert self.org, "No org slug passed"
        url = f'{self.callisto.host}/dione/api/v1/experiments/{experimentId}?orgId={self.org}'
        data = json.dumps({ "bestModel": model_path})
        response = requests.put(
                                url=url,
                                data=data,
                                headers=self.callisto.headers
                                )  
        if response.status_code == 200:
            print ("Experiment updated with best model path")
        else:
            print ("Failed to update experiment with best model path!")

    def experiment_done(self, experimentId):
        assert self.org, "No org slug passed"
        url = f'{self.callisto.host}/dione/api/v1/experiments/{experimentId}?orgId={self.org}'
        response = requests.put(
                                url=url,
                                data=json.dumps({ "status": "success"}),
                                headers=self.callisto.headers
                                )  
        if response.status_code != 200:
            print ("Failed to update experiment status")

    def get_experiments(self, projectId):
        assert self.org, "No org slug passed"
        assert projectId, "No projectId given"

        get_experiment_url = f'{self.callisto.host}/dione/api/v1/experiments?orgId={self.org}&projectId={projectId}'
        response = requests.get(get_experiment_url, headers=self.callisto.headers)

        if response.status_code == 200:
            experiments = response.json()['results']
            headers = ["ID", "ExportId", "Name", "Tags", "Status"]
            table = [[experiment["id"], experiment["exportId"],
                    experiment["name"], ','.join(experiment["tags"]), 
                    experiment["status"]] for experiment in experiments]

            print(f'\nList of experiments for GeoEngine project {projectId}:\n')
            print(tabulate(table, headers=headers, tablefmt='pretty'))
            print()
        else:
            print(f'All experiments for GeoEngine project {projectId} cannot be retrieved')
            print(f'Experiments endpoint {get_experiment_url} returned with HTTP status code : {response.status_code}\n')


    def create_artifact(self, artifact):
        assert self.org, "No org slug passed"
        assert artifact, "No artifact passed"

        url = f'{self.callisto.host}/dione/api/v1/artifacts?orgId={self.org}'

        response = requests.post(url=url, data=json.dumps(artifact), 
                                headers=self.callisto.headers)

        if response.status_code == 200:
            artifact_id = response.json()["artifact"]["id"]
            return artifact_id
        else:
            print ("Failed to create artifact")
            return None

    def send_heartbeat(self, experimentId):
        url = f'{self.callisto.host}/dione/api/v1/experiments/{experimentId}?orgId={self.org}'

        response = requests.patch(url=url, data={}, headers=self.callisto.headers)

        if response.status_code == 200:
            experiment_status = response.json()["experiment"]["status"]
            return experiment_status
        else:
            print ("Failed to send heartbeat")
            return None


import yaml
import click 
import json
import pprint
from InquirerPy.base.control import Choice
from InquirerPy.utils import color_print

from colorama import Fore, Style

from engine.connections import Callisto, Europa, Neso
from engine.libs.inquirer import select, confirm, filepath


@click.command()
def projects():
    """List all the project available in GeoEngine

    Examples:

    \b
    $ engine projects
    """
    callisto = Callisto()
    choose_public_private = select(
        message="Which type of projects do you want to see?",
        choices=["Open-Source", "From my organization"],
        qmark="\U0001F310",
        amark="\U0001F310"
    )
    print ()
    org = None
    if choose_public_private == "From my organization":
        orgs = callisto.get_orgs()
        org_choices = [Choice(org, name=org["name"]) for org in orgs]
        org = select(
            message="Please select an organization",
            choices=org_choices,
            qmark="\U0001F3E2",
            amark="\U0001F3E2"
        )
        print ()

    if org:
        europa = Europa(callisto, org["id"])
    else:
        europa = Europa(callisto)
    
    projects = europa.get_projects()
    project_choices = [Choice(project, name=project["name"]) for project in projects]
    project = select(
        message="Please select a project",
        choices=project_choices,
        qmark="\U0001F4C1",
        amark="\U0001F4C1"
    )
    print ()

    show_detail = confirm(
        message=f"Do you want to see {project['name']} details?",
        qmark="\U0001F4C2",
        amark="\U0001F4C2"
       )

    if show_detail:
        if project["description"]:
            print (Fore.GREEN + "Description : " + Style.RESET_ALL, end="")
            print (Fore.GREEN + project['description'] + Style.RESET_ALL)

        if project["sensorIds"]:
            print (Fore.GREEN + "Sensors : " + Style.RESET_ALL, end="")
            neso = Neso(callisto, None)
            sensors = neso.get_sensors()
            sensor_ids = project['sensorIds']
            sensor_names = [sensors[sensor_id]["name"] for sensor_id in sensor_ids]
            print (Fore.GREEN + ', '.join(sensor_names) + Style.RESET_ALL)

        if project["problemType"]:
            print (Fore.GREEN + "Problem Type : " + Style.RESET_ALL, end="")
            print (Fore.GREEN + project['problemType'] + Style.RESET_ALL)

        if project["details"]:
            print (Fore.CYAN + project['details'].split('\n')[0] + Style.RESET_ALL)
        
        if project["bibtex"]:
            print (Fore.MAGENTA + project['bibtex'] + Style.RESET_ALL)
    print ()

    show_exports = confirm(
        message=f"Do you want to see {project['name']} exports?",
        qmark="\U0001F6A7",
        amark="\U0001F6A7"
       )
    print ()

    if show_exports:
        if org:
            europa = Europa(callisto, org['id'])
        else:
            europa = Europa(callisto)
        exports = europa.get_project_exports(project["id"])

        choices = []
        for _, export in exports.items():
            if export['status'] == 'completed':
                choice = f"{export['name']} has "
                formats = export['formats']
                if len(formats) > 2:
                    choice += f"{', '.join(formats[:-1])}, and {str(formats[-1])} formats"
                elif len(formats) == 2:
                    choice += f"{' and '.join(formats)} fromats"
                elif len(formats) == 1:
                    choice += f"{formats[0]} format" 
                if export['designated']:
                    choice += f" and is a deisgnated export of {project['name']}"
                choice += "."
                choices.append(Choice(export, name=choice))

        export = select(
            message="Please select an export",
            choices=choices,
            qmark="\U0001F6A7",
            amark="\U0001F6A7"
            )
        print ()

        text = [("#F7F7F7", "Do you want to generate a experiment tracking configuration for ")]
        if org:
            text += [("#3AB222", org['name']), ("#F7F7F7", "'s ")]
        text += [("#B4195D", project['name']),
                ("#F7F7F7", " with "),
                ("#B29822", export['name']),
                ("#F7F7F7", " export?")]
        color_print(text)
        want_config = confirm(message="", qmark="\U0001F913", amark="\U0001F913")
        print ()

        if want_config:
            project_org = None
            orgs = callisto.get_orgs()
            for org in orgs:
                if project["orgId"] == org["id"]:
                    project_org = org
                    break
            if not project_org:
                click.echo("Please visit https://engine.granular.ai to clone the project.")
            else:       
                which_config = select(
                    message="In which format do you want the configuration file?",
                    choices=["YAML", 
                            "JSON", 
                            "Py config file for geo-libs"],
                    qmark="\U0001F4DD",
                    amark="\U0001F4DD"
                )
                print ()

                
                config = {"name": project["name"],
                        "description": project["description"],
                        "tags": project["tags"],
                        "org": project_org["slug"],
                        "exportId": export["id"],
                        "projectId": project["id"],
                        "framework": "pytorch",
                        "gitUrl": "",
                        "metaInfo": "",
                        "params": None,
                        "inputs": None,
                        "outputs": None}
                
                save_path = filepath(
                    message="Please enter a path to save the configuration",
                    qmark="\U0001F4E9",
                    amark="\U0001F4E9"
                    )
                if which_config == 'YAML':
                    if '.yaml' not in save_path:
                        save_path += '.yaml'

                    with open(save_path, 'w') as fout:
                        yaml.dump(config, fout)
                        print ("Saved to " + Fore.GREEN + save_path + Style.RESET_ALL)
                elif which_config == 'JSON':
                    if '.json' not in save_path:
                        save_path += '.json'
                    
                    with open(save_path, 'w') as fout:
                        json.dump(config, fout, indent=4)
                        print ("Saved to " + Fore.GREEN + save_path + Style.RESET_ALL)  
                else:
                    if '.py' not in save_path:
                        save_path += '.py'
                    
                    with open(save_path, 'w') as fout:
                        fout.write("_base_ = [\n\t'../_base_/default_runtime.py'\n]\n\n")
                        pp = pprint.PrettyPrinter(indent=4)
                        fout.write(f"engine = {pp.pformat(config)}")
                        print ("Saved to " + Fore.GREEN + save_path + Style.RESET_ALL)
                            
    return


# -*- coding: utf-8 -*-
"""Top-level package for Granular phobos."""
from engine.grain import Engine 

__author__ = """Sid Gupta, Sagar Verma"""
__email__ = 'sid@granular.ai, sagar@granular.ai'
__version__ = 'v0.2.0'

__all__ = ["Engine"]


import requests

from tabulate import tabulate


__all__ = ["Europa"]

class Europa:
    def __init__(self, callisto=None, org=None):
        self.callisto = callisto
        self.org = org

    def get_labels(self, properties, labelmaps):
        labels = { key: [] for res in properties['responses'] for key in res }
        
        for res in properties['responses']:
            for key in res:
                labels[key].append(res[key][0])

        for key in labels:
            llist = []
            for i in range(len(labels[key])):
                llist.append(labelmaps[i][labels[key][i]])
            labels[key] = llist
        
        return labels

    def get_image_details(self, id):
        image_url = f'{self.callisto.host}/europa/api/v1/images/{id}'

        response = requests.get(image_url, headers=self.callisto.headers)

        if response.status_code == 200:
            image = response.json()['image']
            return image['tiles'], image['geometry'], image['status']
        else:
            print(f'Image details cannot be retrieved')
            print(f'Image meta endpoint {image_url} returned with HTTP status code : {response.status_code}')
            return None, None, None
            
    def get_projects(self):
        if self.org:
            get_project_url = f'{self.callisto.host}/europa/api/v1/tasks?orgId={self.org}'
        else:
            get_project_url = f"{self.callisto.host}/europa/api/v1/tasks?search=&status=all&isPublic=true"
        response = requests.get(get_project_url, headers=self.callisto.headers)

        if response.status_code == 200:
            projects = response.json()['results']

            return projects
        else:
            print(f'All GeoEngine projects cannot be retrieved')
            print(f'Projects endpoint {get_project_url} returned with HTTP status code : {response.status_code}\n')
            return None

    def get_project_details(self, id, verbose=True):
        if self.org:
            project_details_url = f'{self.callisto.host}/europa/api/v1/tasks/{id}?orgId={self.org}'
        else:
            project_details_url = f"{self.callisto.host}/europa/api/v1/tasks/{id}?search=&status=all&isPublic=true"

        response = requests.get(project_details_url, headers=self.callisto.headers)
        
        if response.status_code == 200:
            project = response.json()['task']
            
            if verbose:
                ignorelist = ['populateCounter', 'owner', 'createdAt', 'updatedAt', 'deteledAt', 'annotators']
                print('\Project Details:\n')
            
                for key in project.keys():
                    if key == 'questions':
                        print(key+' : \n')
                        for qstn in project[key]:
                            print('name : {}'.format(qstn['name']))
                            print('description : {}'.format(qstn['description']))
                            print('response options : {}'.format(qstn['responseOptions']))
                            print()
                    elif key not in ignorelist:
                        print('{} : {}'.format(key, project[key]))

                print()
            return project
        else:
            print(f'Project details cannot be retrieved')
            print(f'Project details endpoint {project_details_url} returned with HTTP status code : {response.status_code}\n')
            return None 
            
    # def export_annotations(self, id):
    #     export_url = f'{self.callisto.host}/europa/api/v1/tasks/{id}/export'

    #     print(f'exporting annotations for task id : {id}')

    #     response = requests.post(export_url, headers=self.callisto.headers)

    #     if response.status_code != 200:
    #         print('cannot export annotations')
    #         print(f'export endpoint {export_url} returned with HTTP status code : {response.status_code}\n')
    #         return
    #     else:
    #         print('annotations export requested')

    
    def get_project_exports(self, id):
        if self.org:
            project_exports_url = f'{self.callisto.host}/europa/api/v1/tasks/{id}/datasets?orgId={self.org}'
        else:
            project_exports_url = f"{self.callisto.host}/europa/api/v1/tasks/{id}/datasets?search=&status=all&isPublic=true"

        response = requests.get(project_exports_url, headers=self.callisto.headers)
        
        response = requests.get(project_exports_url, headers=self.callisto.headers)

        if response.status_code == 200:
            exports = response.json()['results']
            exports = {export["name"]: export for export in exports}
            
            return exports
        else:
            print(f'All exports for GeoEngine project {id} cannot be retrieved')
            print(f'Exports endpoint {project_exports_url} returned with HTTP status code : {response.status_code}\n')
            return None


import os 
import json 
import requests 
import click
import keyring
from appdirs import user_config_dir 

from colorama import Back, Fore, Style


__all__ = ['Callisto']

class Callisto:
    def __init__(self, email=None, password=None,
                host=None):
        self.host = host
        self.email = email 
        self.password = password
        self.user = None
        self.headers = {
            'accept': 'application/json',
            'Content-Type': 'application/json'
        }
        self.setup()

    def read_config(self):
        try:
            config_path = os.path.join(user_config_dir('engine'), "config.json")
            fin = open(config_path, 'r')
            config_data = json.load(fin)
            fin.close()

            if not self.host:
                self.host = config_data['host']
            if not self.email:
                self.email = config_data['email']
            if not self.password:
                try:
                    self.password = keyring.get_password("engine", self.email)
                except:
                    self.password = config_data['password']
            try:
                self.headers['Cookie'] = keyring.get_password("engine-cookie", self.email)
            except:
                self.headers['Cookie'] = config_data['Cookie']
        except:
            pass

    def update_config(self):
        config_path = os.path.join(user_config_dir('engine'), "config.json")
        fout = open(config_path, 'w')
        try:
            keyring.set_password("engine", self.email, self.password)
            keyring.set_password("engine-cookie", self.email, self.headers['Cookie'])

            json.dump({'host': self.host,
                        'email': self.email, 
                        # 'password': self.password, 
                        # 'cookie': self.headers['Cookie']
                        }, fout)
        except:
            json.dump({'host': self.host,
                        'email': self.email, 
                        'password': self.password, 
                        'Cookie': self.headers['Cookie']
                        }, fout)
        fout.close()
    
    def is_token_valid(self):
        response = requests.get(f'{self.host}/callisto/api/v1/users/me', headers=self.headers)
        if response.status_code == 200:
            return True 
        return False

    def login(self):
        login_url = f'{self.host}/callisto/auth/v1/login'
        data = {"email": self.email, "password": self.password}
        if 'Cookie' in self.headers:
            del self.headers['Cookie']

        response = requests.post(login_url, headers=self.headers, data=json.dumps(data))
        if response.status_code == 200:
            resdata = response.json()
            self.user = resdata["user"]
            auth_cookie = response.cookies["callisto_auth"]
            self.headers["Cookie"] = f"callisto_auth={auth_cookie}"
            self.update_config()
        else:
            print (Fore.RED  + 'Failed to authenticate' + Style.RESET_ALL)
            print ("Authentication endpoint " + Fore.CYAN + self.host + Style.RESET_ALL +
                  " returned with HTTP status code : " + Fore.RED + str(response.status_code) +
                  Style.RESET_ALL)
            print ("Please register at " + Fore.CYAN + "https://engine.granular.ai/register" + 
                    Style.RESET_ALL + " if you haven't")

    def logout(self):
        logout_url = f'{self.host}/callisto/auth/v1/logout'
        response = requests.post(logout_url, headers=self.headers)
        if response.status_code == 200:
            self.user = None
            self.email = None
            self.password = None
            self.headers['Cookie'] = None 
            self.update_config()
        else:
            print (Fore.RED  + 'Failed to logout' + Style.RESET_ALL)

    def setup(self):
        self.read_config()
        if not self.email or not self.password:
            print (Fore.LIGHTCYAN_EX  + "Please login using email and password" + Style.RESET_ALL)
        else:
            self.login()

    def get_user(self):
        if not self.user:
            url = f"{self.host}/callisto/api/v1/users/me"
            response = requests.get(url, headers=self.headers)
            if response.status_code == 200:
                self.user = response.json()
            else:
                print (Fore.RED + 'Your user details cannot be retrieved' + Style.RESET_ALL)
                return None
        return self.user

    def get_org_id_from_slug(self, org_slug):
        url = f"{self.host}/callisto/api/v1/organizations/{org_slug}"
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            resdata = response.json()
            return resdata['id']
        else:
            print ("Organization slug " + Fore.RED + org_slug + Style.RESET_ALL + " not found")
            return None
            
    def get_orgs(self):
        url = f"{self.host}/callisto/api/v1/organizations"
        response = requests.get(url, headers=self.headers)
        if response.status_code == 200:
            orgs = response.json()
            return orgs
        else:
            click.echo(Fore.RED + 'No organizations found' + Style.RESET_ALL)
            return None


import os
import ctypes
import yaml
import threading
import time
from datetime import datetime

from engine.connections import Callisto, Europa, Dione


__all__ = ["Engine"]

class Engine():
    def __init__(self, yaml_file=None, **kwargs):
        if yaml_file:
            fp = open(yaml_file, 'r')
            meta = dict(yaml.safe_load(fp.read()))
        else:
            meta = kwargs
        assert "org" in meta, "Please provide organization slug"
        assert "projectId" in meta, "No GeoEngine projectId passed"
        assert "exportId" in meta, f"No exportId for GeoEngine project {meta['projectId']} passed"

        self.callisto = Callisto()
        self.org_id = self.callisto.get_org_id_from_slug(org_slug=meta['org'])
        self.europa = Europa(self.callisto, self.org_id)
        project = self.europa.get_project_details(id=meta['projectId'], verbose=False)
        assert "bucketPath" in project, "No bucketPath in the project"

        self.version = f"{meta['name'].replace(' ', '_')}-{datetime.utcnow().strftime('%Y-%m-%d-%H-%M-%S')}"

        meta['experimentUrl'] = f"{project['bucketPath']}/experiments/{self.version}"

        self.meta = meta

        if 'logsDir' not in meta:
            meta['logsDir'] = 'logs'
        elif meta['logsDir'] == '':
            meta['logsDir'] = 'logs'
        if 'weightsDir' not in meta:
            meta['weightsDir'] = 'weights'
        elif meta['weightsDir'] == '':
            meta['weightsDir'] = 'weights'

        if not os.path.exists(meta['logsDir']):
            os.makedirs(meta['logsDir'])
        if not os.path.exists(meta['weightsDir']):
            os.makedirs(meta['weightsDir'])

        proper_meta = {}
        proper = ['metaInfo', 'name', 'description', 'tags', 
                  'exportId', 'projectId', 'gitUrl', 
                  'framework', 'params', 'inputs',
                  'outputs', 'experimentUrl', 'readme']
        for k in meta.keys():
            if k in proper:
                proper_meta[k] = meta[k] or ''

        # Register the experiment on dione
        self.dione = Dione(self.callisto, self.org_id)
        self.experimentId = self.dione.create_experiment(proper_meta)

        self._exit_flag = False

        self._heartbeat_thread = threading.Thread(target=self._heartbeat)
        self._heartbeat_thread.daemon = True 
        self._heartbeat_thread.start()
    
    def _heartbeat(self):
        while True:
            if self._exit_flag:
                return
  
            experiment_status = self.dione.send_heartbeat(self.experimentId)

            # TODO: experiment status can be used to stop an experiment from UI side by ckecking the status

            time.sleep(5)

    def log(self, step, best=False, checkpoint_path=None, **kwargs):
        artifact = {"experimentId": self.experimentId,
                    "metadata": kwargs,
                    "step": step}
        if checkpoint_path:
            dst_state_path = f"{self.meta['experimentUrl']}/weights/"
            os.system(f"gsutil cp {checkpoint_path} {dst_state_path} 2> /dev/null")
            artifact["metadata"]["checkpoint"] = f"{dst_state_path}{checkpoint_path.split('/')[-1]}"
            
            if best:
                self.dione.add_best_model(self.experimentId, artifact["metadata"]["checkpoint"])


        # Register the artifact on dione 
        artifact_id = self.dione.create_artifact(artifact)

    def done(self):
        self.dione.experiment_done(self.experimentId)
        self._exit_flag = True


from InquirerPy import inquirer
from InquirerPy.validator import PathValidator

def select(choices, **kwargs):
    return inquirer.select(
        choices=choices,
        message=kwargs.get("message", "Please select"),
        instruction=kwargs.get("instruction", ""),
        multiselect=kwargs.get("multiselect", False),
        qmark=kwargs.get("qmark", ""),
        amark=kwargs.get("amark", ""),
        pointer=kwargs.get("pointer", "->"),
    ).execute()

def confirm(**kwargs):
    return inquirer.confirm(
        message=kwargs.get("message", ""),
        qmark=kwargs.get("qmark", ""),
        amark=kwargs.get("amark", ""),
        ).execute()

def filepath(message, **kwargs):
    return inquirer.filepath(
        message=message,
        qmark=kwargs.get("qmark", ""),
        amark=kwargs.get("amark", ""),
    ).execute()

def text(message, **kwargs):
    return inquirer.text(
        message=message,
        qmark=kwargs.get("qmark", ""),
        amark=kwargs.get("amark", ""),
        ).execute()

def secret(message, **kwargs):
    return inquirer.secret(
        message=message,
        transformer=lambda _: "[hidden]",
        qmark=kwargs.get("qmark", ""),
        amark=kwargs.get("amark", ""),
    ).execute()


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['engine', 'engine.cli', 'engine.connections', 'engine.libs']

package_data = \
{'': ['*']}

install_requires = \
['appdirs>=1.4.4,<2.0.0',
 'click>=8.1.3,<9.0.0',
 'colorama>=0.4.6,<0.5.0',
 'inquirerpy>=0.3.4,<0.4.0',
 'keyring>=23.11.0,<24.0.0',
 'keyrings-alt>=4.2.0,<5.0.0',
 'passlib>=1.7.4,<2.0.0',
 'tabulate>=0.9.0,<0.10.0',
 'yacs>=0.1.8,<0.2.0']

entry_points = \
{'console_scripts': ['engine = engine.cli:cli']}

setup_kwargs = {
    'name': 'granular-engine',
    'version': '0.2.0',
    'description': 'Experiment tracking for GeoSpatial Machine Learning on GeoEngine',
    'long_description': '===================\nEngine\n===================\n\nA Utility Library that assists in Geospatial Machine Learning Experiment Tracking.\n\nInstallation\n------------\n\n```pip install granular-engine```\n\n\nUsage\n-----\n\n>>> from engine import Engine\n>>>\n>>> # Make a config.yaml with GeoEngine projectId and exportId and other necessary details\n>>> engine = Engine("config.yaml")\n>>>\n>>> for epoch in enumerate(epochs):\n>>>   # train \n>>>   # eval\n>>>   engine.log(step=epoch, train_loss=train_loss, val_loss=val_loss)\n>>>\n>>> engine.done()\n\n\nLicense\n-------\nGPLv3\n\nDocumentation\n-------------\n\nView documentation `here <https://engine.granular.ai/>`_\n',
    'author': 'Sagar Verma',
    'author_email': 'sagar@granular.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/granularai/engine',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.0,<4.0.0',
}


setup(**setup_kwargs)



from subprocess import call
import click 

from engine.connections import Callisto
from engine.connections import Dione 


@click.group()
@click.pass_context
def experiment(ctx):
    if ctx.invoked_subcommand is None:
        click.echo('Preparing GeoEngine project for training')

@experiment.command()
@click.option('--org', required=True, type=str, 
              help='Organization to which the project belongs')
@click.option('--projectid', required=True, type=str, 
              help='Project for which experiments to show')
def ls(org, projectid):
    """List all the experiments available for a project in GeoEngine

    Examples:

    \b
    $ engine experiments ls --projectId=PROJECT_ID --org=ORG_SLUG
    """
    print (projectid)
    callisto = Callisto()
    if org:
        org_id = callisto.get_org_id_from_slug(org_slug=org)
        if org_id:
            europa = Dione(callisto, org_id)
            europa.get_experiments(projectid)
    return 